@@ -1,7 +1,7 @@
 from django.urls import reverse
 
-from nautobot.circuits.choices import *
-from nautobot.circuits.models import Circuit, CircuitTermination, CircuitType, Provider
+from nautobot.circuits.choices import CircuitTerminationSideChoices
+from nautobot.circuits.models import Circuit, CircuitTermination, CircuitType, Provider, ProviderNetwork
 from nautobot.dcim.models import Site
 from nautobot.extras.models import Status
 from nautobot.utilities.testing import APITestCase, APIViewTestCases
@@ -10,7 +10,7 @@ from nautobot.utilities.testing import APITestCase, APIViewTestCases
 class AppTest(APITestCase):
     def test_root(self):
         url = reverse("circuits-api:api-root")
-        response = self.client.get("{}?format=api".format(url), **self.header)
+        response = self.client.get(f"{url}?format=api", **self.header)
 
         self.assertEqual(response.status_code, 200)
 
@@ -31,10 +31,12 @@ class ProviderTest(APIViewTestCases.APIViewTestCase):
             "name": "Provider 6",
             "slug": "provider-6",
         },
+        {"name": "Provider 7"},
     ]
     bulk_update_data = {
         "asn": 1234,
     }
+    slug_source = "name"
 
     @classmethod
     def setUpTestData(cls):
@@ -44,6 +46,49 @@ class ProviderTest(APIViewTestCases.APIViewTestCase):
         Provider.objects.create(name="Provider 3", slug="provider-3")
 
 
+class ProviderNetworkTest(APIViewTestCases.APIViewTestCase):
+    model = ProviderNetwork
+    brief_fields = ["display", "id", "name", "slug", "url"]
+
+    @classmethod
+    def setUpTestData(cls):
+        providers = (
+            Provider(name="Provider 1", slug="provider-1"),
+            Provider(name="Provider 2", slug="provider-2"),
+        )
+        Provider.objects.bulk_create(providers)
+
+        provider_networks = (
+            ProviderNetwork(name="Provider Network 1", slug="provider-network-1", provider=providers[0]),
+            ProviderNetwork(name="Provider Network 2", slug="provider-network-2", provider=providers[0]),
+            ProviderNetwork(name="Provider Network 3", slug="provider-network-3", provider=providers[0]),
+        )
+        ProviderNetwork.objects.bulk_create(provider_networks)
+
+        cls.create_data = [
+            {
+                "name": "Provider Network 4",
+                "slug": "provider-network-4",
+                "provider": providers[0].pk,
+            },
+            {
+                "name": "Provider Network 5",
+                "slug": "provider-network-5",
+                "provider": providers[0].pk,
+            },
+            {
+                "name": "Provider Network 6",
+                "slug": "provider-network-6",
+                "provider": providers[0].pk,
+            },
+        ]
+
+        cls.bulk_update_data = {
+            "provider": providers[1].pk,
+            "description": "New description",
+        }
+
+
 class CircuitTypeTest(APIViewTestCases.APIViewTestCase):
     model = CircuitType
     brief_fields = ["circuit_count", "display", "id", "name", "slug", "url"]
@@ -60,10 +105,12 @@ class CircuitTypeTest(APIViewTestCases.APIViewTestCase):
             "name": "Circuit Type 6",
             "slug": "circuit-type-6",
         },
+        {"name": "Circuit Type 7"},
     )
     bulk_update_data = {
         "description": "New description",
     }
+    slug_source = "name"
 
     @classmethod
     def setUpTestData(cls):
