@@ -336,7 +336,7 @@ class APIRootView(NautobotAPIVersionMixin, APIView):
         return "API Root"
 
     @extend_schema(exclude=True)
-    def get(self, request, format=None):
+    def get(self, request, format=None):  # pylint: disable=redefined-builtin
 
         return Response(
             OrderedDict(
@@ -418,7 +418,7 @@ class StatusView(NautobotAPIVersionMixin, APIView):
                 if isinstance(version, tuple):
                     version = ".".join(str(n) for n in version)
             installed_apps[app_config.name] = version
-        installed_apps = {k: v for k, v in sorted(installed_apps.items())}
+        installed_apps = dict(sorted(installed_apps.items()))
 
         # Gather installed plugins
         plugins = {}
@@ -426,7 +426,7 @@ class StatusView(NautobotAPIVersionMixin, APIView):
             plugin_name = plugin_name.rsplit(".", 1)[-1]
             plugin_config = apps.get_app_config(plugin_name)
             plugins[plugin_name] = getattr(plugin_config, "version", None)
-        plugins = {k: v for k, v in sorted(plugins.items())}
+        plugins = dict(sorted(plugins.items()))
 
         # Gather Celery workers
         workers = celery_app.control.inspect().active()  # list or None
@@ -593,7 +593,7 @@ class GraphQLDRFAPIView(NautobotAPIVersionMixin, APIView):
         Returns:
             response (dict), status_code (int): Payload of the response to send and the status code.
         """
-        query, variables, operation_name, id = GraphQLView.get_graphql_params(request, data)
+        query, variables, operation_name, _id = GraphQLView.get_graphql_params(request, data)
 
         execution_result = self.execute_graphql_request(request, data, query, variables, operation_name)
 
