@@ -29,7 +29,7 @@ class ChangeLoggedModel(models.Model):
     class Meta:
         abstract = True
 
-    def to_objectchange(self, action, related_object=None, object_data_extra=None, object_data_exclude=None):
+    def to_objectchange(self, action, *, related_object=None, object_data_extra=None, object_data_exclude=None):
         """
         Return a new ObjectChange representing a change made to this object. This will typically be called automatically
         by ChangeLoggingMiddleware.
@@ -63,6 +63,8 @@ class ChangeLoggedModel(models.Model):
             except NoReverseMatch:
                 continue
 
+        return None
+
 
 @extras_features("graphql")
 class ObjectChange(BaseModel):
@@ -138,12 +140,7 @@ class ObjectChange(BaseModel):
         ]
 
     def __str__(self):
-        return "{} {} {} by {}".format(
-            self.changed_object_type,
-            self.object_repr,
-            self.get_action_display().lower(),
-            self.user_name,
-        )
+        return f"{self.changed_object_type} {self.object_repr} {self.get_action_display().lower()} by {self.user_name}"
 
     def save(self, *args, **kwargs):
 
