@@ -41,6 +41,7 @@ def _get_user_if_authenticated(user, objectchange):
         return user
     else:
         logger.warning(f"Unable to retrieve the user while creating the changelog for {objectchange.changed_object}")
+        return None
 
 
 def _handle_changed_object(change_context, sender, instance, **kwargs):
@@ -49,7 +50,7 @@ def _handle_changed_object(change_context, sender, instance, **kwargs):
     """
     from .jobs import enqueue_job_hooks  # avoid circular import
 
-    m2m_changed = False
+    object_m2m_changed = False
 
     # Determine the type of change being made
     if kwargs.get("created"):
@@ -58,14 +59,14 @@ def _handle_changed_object(change_context, sender, instance, **kwargs):
         action = ObjectChangeActionChoices.ACTION_UPDATE
     elif kwargs.get("action") in ["post_add", "post_remove"] and kwargs["pk_set"]:
         # m2m_changed with objects added or removed
-        m2m_changed = True
+        object_m2m_changed = True
         action = ObjectChangeActionChoices.ACTION_UPDATE
     else:
         return
 
     # Record an ObjectChange if applicable
     if hasattr(instance, "to_objectchange"):
-        if m2m_changed:
+        if object_m2m_changed:
             related_changes = ObjectChange.objects.filter(
                 changed_object_type=ContentType.objects.get_for_model(instance),
                 changed_object_id=instance.pk,
@@ -257,7 +258,7 @@ def refresh_job_models(sender, *, apps, **kwargs):
     Callback for the nautobot_database_ready signal; updates Jobs in the database based on Job source file availability.
     """
     Job = apps.get_model("extras", "Job")
-    GitRepository = apps.get_model("extras", "GitRepository")
+    GitRepository = apps.get_model("extras", "GitRepository")  # pylint: disable=redefined-outer-name
 
     # To make reverse migrations safe
     if not hasattr(Job, "job_class_name") or not hasattr(Job, "git_repository"):
@@ -278,8 +279,8 @@ def refresh_job_models(sender, *, apps, **kwargs):
                 logger.warning('GitRepository "%s" not found?', source[4:])
             source = "git"
 
-        for module_name, module_details in modules.items():
-            for job_class_name, job_class in module_details["jobs"].items():
+        for module_details in modules.values():
+            for job_class in module_details["jobs"].values():
                 # TODO: catch DB error in case where multiple Jobs have the same grouping + name
                 job_model, _ = refresh_job_model_from_job_class(Job, source, job_class, git_repository=git_repository)
                 if job_model is not None:
