@@ -302,13 +302,9 @@ class PrefixLengthSerializer(serializers.Serializer):
 
         prefix = self.context.get("prefix")
         if prefix.family == 4 and requested_prefix > 32:
-            raise serializers.ValidationError(
-                {"prefix_length": "Invalid prefix length ({}) for IPv4".format((requested_prefix))}
-            )
+            raise serializers.ValidationError({"prefix_length": f"Invalid prefix length ({requested_prefix}) for IPv4"})
         elif prefix.family == 6 and requested_prefix > 128:
-            raise serializers.ValidationError(
-                {"prefix_length": "Invalid prefix length ({}) for IPv6".format((requested_prefix))}
-            )
+            raise serializers.ValidationError({"prefix_length": f"Invalid prefix length ({requested_prefix}) for IPv6"})
         return data
 
 
@@ -407,7 +403,7 @@ class AvailableIPSerializer(serializers.Serializer):
         return OrderedDict(
             [
                 ("family", self.context["prefix"].version),
-                ("address", "{}/{}".format(instance, self.context["prefix"].prefixlen)),
+                ("address", f"{instance}/{self.context['prefix'].prefixlen}"),
                 ("vrf", vrf),
             ]
         )
