@@ -1,8 +1,11 @@
 import django_filters
 
+from nautobot.dcim.models import Location
 from nautobot.extras.filters import NautobotFilterSet
 from nautobot.utilities.filters import (
     NameSlugSearchFilterSet,
+    NaturalKeyOrPKMultipleChoiceFilter,
+    RelatedMembershipBooleanFilter,
     SearchFilter,
     TagFilter,
     TreeNodeMultipleChoiceFilter,
@@ -46,16 +49,22 @@ class TenantFilterSet(NautobotFilterSet):
     group_id = TreeNodeMultipleChoiceFilter(
         queryset=TenantGroup.objects.all(),
         field_name="group",
-        lookup_expr="in",
         label="Tenant group (ID)",
     )
     group = TreeNodeMultipleChoiceFilter(
         queryset=TenantGroup.objects.all(),
         field_name="group",
-        lookup_expr="in",
         to_field_name="slug",
         label="Tenant group (slug)",
     )
+    locations = TreeNodeMultipleChoiceFilter(
+        queryset=Location.objects.all(),
+        label="Locations (slugs and/or IDs)",
+    )
+    has_locations = RelatedMembershipBooleanFilter(
+        field_name="locations",
+        label="Has locations",
+    )
     tag = TagFilter()
 
     class Meta:
@@ -63,6 +72,7 @@ class TenantFilterSet(NautobotFilterSet):
         fields = ["id", "name", "slug"]
 
 
+# TODO: should be TenancyFilterSetMixin
 class TenancyFilterSet(django_filters.FilterSet):
     """
     An inheritable FilterSet for models which support Tenant assignment.
@@ -71,23 +81,19 @@ class TenancyFilterSet(django_filters.FilterSet):
     tenant_group_id = TreeNodeMultipleChoiceFilter(
         queryset=TenantGroup.objects.all(),
         field_name="tenant__group",
-        lookup_expr="in",
         label="Tenant Group (ID)",
     )
     tenant_group = TreeNodeMultipleChoiceFilter(
         queryset=TenantGroup.objects.all(),
         field_name="tenant__group",
         to_field_name="slug",
-        lookup_expr="in",
         label="Tenant Group (slug)",
     )
     tenant_id = django_filters.ModelMultipleChoiceFilter(
         queryset=Tenant.objects.all(),
-        label="Tenant (ID)",
+        label='Tenant (ID) (deprecated, use "tenant" filter instead)',
     )
-    tenant = django_filters.ModelMultipleChoiceFilter(
+    tenant = NaturalKeyOrPKMultipleChoiceFilter(
         queryset=Tenant.objects.all(),
-        field_name="tenant__slug",
-        to_field_name="slug",
-        label="Tenant (slug)",
+        label="Tenant (slug or ID)",
     )
