@@ -20,7 +20,7 @@ class AppTest(APITestCase):
     def test_root(self):
 
         url = reverse("users-api:api-root")
-        response = self.client.get("{}?format=api".format(url), **self.header)
+        response = self.client.get(f"{url}?format=api", **self.header)
 
         self.assertEqual(response.status_code, 200)
 
@@ -130,7 +130,7 @@ class TokenTest(APIViewTestCases.APIViewTestCase):
         """
         credentials = f"{username}:{password}"
         base64_credentials = base64.b64encode(credentials.encode(HTTP_HEADER_ENCODING)).decode(HTTP_HEADER_ENCODING)
-        return "Basic %s" % base64_credentials
+        return f"Basic {base64_credentials}"
 
     def test_create_token_basic_authentication(self):
         """
