@@ -10,24 +10,26 @@ from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.postgres.forms import SimpleArrayField
 from django.core.exceptions import MultipleObjectsReturned, ObjectDoesNotExist, ValidationError
-from django.db.models import Count
+from django.db.models import Count, Q
 from django.forms.fields import BoundField, JSONField as _JSONField, InvalidJSONInput
 from django.urls import reverse
 
 from nautobot.extras.utils import FeatureQuery
 from nautobot.utilities.choices import unpack_grouped_choices
+from nautobot.utilities.utils import is_uuid
 from nautobot.utilities.validators import EnhancedURLValidator
 from . import widgets
-from .constants import *
-from .utils import expand_alphanumeric_pattern, expand_ipaddress_pattern, parse_numeric_range
+from .constants import ALPHANUMERIC_EXPANSION_PATTERN, IP4_EXPANSION_PATTERN, IP6_EXPANSION_PATTERN
+from .utils import expand_alphanumeric_pattern, expand_ipaddress_pattern, parse_numeric_range, parse_csv, validate_csv
 
 __all__ = (
     "CommentField",
     "CSVChoiceField",
     "CSVContentTypeField",
-    "CSVMultipleChoiceField",
     "CSVDataField",
+    "CSVFileField",
     "CSVModelChoiceField",
+    "CSVMultipleChoiceField",
     "CSVMultipleContentTypeField",
     "DynamicModelChoiceField",
     "DynamicModelMultipleChoiceField",
@@ -35,9 +37,10 @@ __all__ = (
     "ExpandableNameField",
     "JSONField",
     "JSONArrayFormField",
-    "MultipleContentTypeField",
-    "NumericArrayField",
     "LaxURLField",
+    "MultipleContentTypeField",
+    "MultiMatchModelMultipleChoiceField",
+    "NumericArrayField",
     "SlugField",
     "TagFilterField",
 )
@@ -76,47 +79,66 @@ class CSVDataField(forms.CharField):
             )
 
     def to_python(self, value):
-
-        records = []
+        if value is None:
+            return None
         reader = csv.reader(StringIO(value.strip()))
+        return parse_csv(reader)
 
-        # Consume the first line of CSV data as column headers. Create a dictionary mapping each header to an optional
-        # "to" field specifying how the related object is being referenced. For example, importing a Device might use a
-        # `site.slug` header, to indicate the related site is being referenced by its slug.
-        headers = {}
-        for header in next(reader):
-            if "." in header:
-                field, to_field = header.split(".", 1)
-                headers[field] = to_field
-            else:
-                headers[header] = None
+    def validate(self, value):
+        if value is None:
+            return None
+        headers, _records = value
+        validate_csv(headers, self.fields, self.required_fields)
 
-        # Parse CSV rows into a list of dictionaries mapped from the column headers.
-        for i, row in enumerate(reader, start=1):
-            if len(row) != len(headers):
-                raise forms.ValidationError(f"Row {i}: Expected {len(headers)} columns but found {len(row)}")
-            row = [col.strip() for col in row]
-            record = dict(zip(headers.keys(), row))
-            records.append(record)
+        return value
+
+
+class CSVFileField(forms.FileField):
+    """
+    A FileField (rendered as a ClearableFileInput) which accepts a file containing CSV-formatted data. It returns
+    data as a two-tuple: The first item is a dictionary of column headers, mapping field names to the attribute
+    by which they match a related object (where applicable). The second item is a list of dictionaries, each
+    representing a discrete row of CSV data.
+
+    :param from_form: The form from which the field derives its validation rules.
+    """
+
+    def __init__(self, from_form, *args, **kwargs):
+
+        form = from_form()
+        self.model = form.Meta.model
+        self.fields = form.fields
+        self.required_fields = [name for name, field in form.fields.items() if field.required]
+
+        super().__init__(*args, **kwargs)
+
+        if not self.label:
+            self.label = "CSV File"
+        if not self.help_text:
+            self.help_text = (
+                "Select a CSV file to upload. It should contain column headers in the first row and use commas "
+                "to separate values. Multi-line data and values containing commas may be wrapped "
+                "in double quotes."
+            )
+
+    def to_python(self, file):
+        if file is None:
+            return None
+
+        file = super().to_python(file)
+        csv_str = file.read().decode("utf-8-sig").strip()
+        dialect = csv.Sniffer().sniff(csv_str)
+        reader = csv.reader(csv_str.splitlines(), dialect)
+        headers, records = parse_csv(reader)
 
         return headers, records
 
     def validate(self, value):
-        headers, records = value
+        if value is None:
+            return None
 
-        # Validate provided column headers
-        for field, to_field in headers.items():
-            if field not in self.fields:
-                raise forms.ValidationError(f'Unexpected column header "{field}" found.')
-            if to_field and not hasattr(self.fields[field], "to_field_name"):
-                raise forms.ValidationError(f'Column "{field}" is not a related object; cannot use dots')
-            if to_field and not hasattr(self.fields[field].queryset.model, to_field):
-                raise forms.ValidationError(f'Invalid related object attribute for column "{field}": {to_field}')
-
-        # Validate required fields
-        for f in self.required_fields:
-            if f not in headers:
-                raise forms.ValidationError(f'Required column header "{f}" not found.')
+        headers, _records = value
+        validate_csv(headers, self.fields, self.required_fields)
 
         return value
 
@@ -168,19 +190,38 @@ class CSVModelChoiceField(forms.ModelChoiceField):
 
 class CSVContentTypeField(CSVModelChoiceField):
     """
-    Reference a ContentType in the form <app>.<model>
+    Reference a ContentType in the form `{app_label}.{model}`.
     """
 
     STATIC_CHOICES = True
 
     def prepare_value(self, value):
+        """
+        Allow this field to support `{app_label}.{model}` style, null values, or PK-based lookups
+        depending on how the field is used.
+        """
+        if value is None:
+            return ""
+
+        # Only pass through strings if they aren't numeric. Otherwise cast to `int`.
+        if isinstance(value, str):
+            if not value.isdigit():
+                return value
+            else:
+                value = int(value)
+
+        # Integers are PKs
+        if isinstance(value, int):
+            value = self.queryset.get(pk=value)
+
         return f"{value.app_label}.{value.model}"
 
     def to_python(self, value):
+        value = self.prepare_value(value)
         try:
             app_label, model = value.split(".")
         except ValueError:
-            raise forms.ValidationError('Object type must be specified as "<app>.<model>"')
+            raise forms.ValidationError('Object type must be specified as "<app_label>.<model>"')
         try:
             return self.queryset.get(app_label=app_label, model=model)
         except ObjectDoesNotExist:
@@ -192,7 +233,7 @@ class MultipleContentTypeField(forms.ModelMultipleChoiceField):
     Field for choosing any number of `ContentType` objects.
 
     Optionally can restrict the available ContentTypes to those supporting a particular feature only.
-    Optionally can pass the selection through as a list of "`{app_label}.{model}`" strings intead of PK values.
+    Optionally can pass the selection through as a list of `{app_label}.{model}` strings instead of PK values.
     """
 
     STATIC_CHOICES = True
@@ -221,7 +262,7 @@ class MultipleContentTypeField(forms.ModelMultipleChoiceField):
             self.choices = self._string_choices_from_queryset
 
     def _string_choices_from_queryset(self):
-        """Overload choices to return "<app>.<model>" instead of PKs."""
+        """Overload choices to return `{app_label}.{model}` instead of PKs."""
         return [(f"{m.app_label}.{m.model}", m.app_labeled_name) for m in self.queryset.all()]
 
 
@@ -232,7 +273,8 @@ class CSVMultipleContentTypeField(MultipleContentTypeField):
 
     def prepare_value(self, value):
         """Parse a comma-separated string of model names into a list of PKs."""
-        if isinstance(value, str):
+        # "".split(",") yields [""] rather than [], which we don't want!
+        if isinstance(value, str) and value:
             value = value.split(",")
 
         # For each model name, retrieve the model object and extract its
@@ -290,7 +332,7 @@ class ExpandableIPAddressField(forms.CharField):
         super().__init__(*args, **kwargs)
         if not self.help_text:
             self.help_text = (
-                "Specify a numeric range to create multiple IPs.<br />" "Example: <code>192.0.2.[1,5,100-254]/24</code>"
+                "Specify a numeric range to create multiple IPs.<br />Example: <code>192.0.2.[1,5,100-254]/24</code>"
             )
 
     def to_python(self, value):
@@ -329,10 +371,18 @@ class SlugField(forms.SlugField):
     """
 
     def __init__(self, slug_source="name", *args, **kwargs):
-        label = kwargs.pop("label", "Slug")
-        help_text = kwargs.pop("help_text", "URL-friendly unique shorthand")
-        widget = kwargs.pop("widget", widgets.SlugWidget)
-        super().__init__(label=label, help_text=help_text, widget=widget, *args, **kwargs)
+        """
+        Instantiate a SlugField.
+
+        Args:
+            slug_source (str, tuple): Name of the field (or a list of field names) that will be used to suggest a slug.
+        """
+        kwargs.setdefault("label", "Slug")
+        kwargs.setdefault("help_text", "URL-friendly unique shorthand")
+        kwargs.setdefault("widget", widgets.SlugWidget)
+        super().__init__(*args, **kwargs)
+        if isinstance(slug_source, (tuple, list)):
+            slug_source = " ".join(slug_source)
         self.widget.attrs["slug-source"] = slug_source
 
 
@@ -348,7 +398,7 @@ class TagFilterField(forms.MultipleChoiceField):
     def __init__(self, model, *args, **kwargs):
         def get_choices():
             tags = model.tags.annotate(count=Count("extras_taggeditem_items")).order_by("name")
-            return [(str(tag.slug), "{} ({})".format(tag.name, tag.count)) for tag in tags]
+            return [(str(tag.slug), f"{tag.name} ({tag.count})") for tag in tags]
 
         # Choices are fetched each time the form is initialized
         super().__init__(label="Tags", choices=get_choices, required=False, *args, **kwargs)
@@ -365,7 +415,7 @@ class DynamicModelChoiceMixin:
     :param brief_mode: Use the "brief" format (?brief=true) when making API requests (default)
     """
 
-    filter = django_filters.ModelChoiceFilter
+    filter = django_filters.ModelChoiceFilter  # TODO can we change this? pylint: disable=redefined-builtin
     widget = widgets.APISelect
 
     def __init__(
@@ -437,9 +487,9 @@ class DynamicModelChoiceMixin:
         data = bound_field.value()
         if data:
             field_name = getattr(self, "to_field_name") or "pk"
-            filter = self.filter(field_name=field_name)
+            filter_ = self.filter(field_name=field_name)
             try:
-                self.queryset = filter.filter(self.queryset, data)
+                self.queryset = filter_.filter(self.queryset, data)
             except TypeError:
                 # Catch any error caused by invalid initial data passed from the user
                 self.queryset = self.queryset.none()
@@ -524,7 +574,13 @@ class JSONField(_JSONField):
             return value
         if value is None:
             return ""
-        return json.dumps(value, sort_keys=True, indent=4)
+        return json.dumps(value, sort_keys=True, indent=4, ensure_ascii=False)
+
+    # TODO: remove this when we upgrade to Django 4
+    def bound_data(self, data, initial):
+        if data is None:
+            return None
+        return super().bound_data(data, initial)
 
 
 class JSONArrayFormField(forms.JSONField):
@@ -629,3 +685,58 @@ class NumericArrayField(SimpleArrayField):
         except ValueError as error:
             raise ValidationError(error)
         return super().to_python(value)
+
+
+class MultiMatchModelMultipleChoiceField(django_filters.fields.ModelMultipleChoiceField):
+    """
+    Filter field to support matching on the PK *or* `to_field_name` fields (defaulting to `slug` if not specified).
+
+    Raises ValidationError if none of the fields match the requested value.
+    """
+
+    def __init__(self, *args, **kwargs):
+        self.natural_key = kwargs.setdefault("to_field_name", "slug")
+        super().__init__(*args, **kwargs)
+
+    def _check_values(self, values):
+        """
+        This method overloads the grandparent method in `django.forms.models.ModelMultipleChoiceField`,
+        re-using some of that method's existing logic and adding support for coupling this field with
+        multiple model fields.
+        """
+        null = self.null_label is not None and values and self.null_value in values
+        if null:
+            values = [v for v in values if v != self.null_value]
+        # deduplicate given values to avoid creating many querysets or
+        # requiring the database backend deduplicate efficiently.
+        try:
+            values = frozenset(values)
+        except TypeError:
+            # list of lists isn't hashable, for example
+            raise ValidationError(
+                self.error_messages["invalid_list"],
+                code="invalid_list",
+            )
+        pk_values = set()
+        natural_key_values = set()
+        for item in values:
+            query = Q()
+            if is_uuid(item):
+                pk_values.add(item)
+                query |= Q(pk=item)
+            else:
+                natural_key_values.add(item)
+                query |= Q(**{self.natural_key: item})
+            qs = self.queryset.filter(query)
+            if not qs.exists():
+                raise ValidationError(
+                    self.error_messages["invalid_choice"],
+                    code="invalid_choice",
+                    params={"value": item},
+                )
+        query = Q(pk__in=pk_values) | Q(**{f"{self.natural_key}__in": natural_key_values})
+        qs = self.queryset.filter(query)
+        result = list(qs)
+        if null:
+            result += [self.null_value]
+        return result
