@@ -35,7 +35,7 @@ class BaseTable(tables.Table):
         obj_type = ContentType.objects.get_for_model(self._meta.model)
 
         for cf in CustomField.objects.filter(content_types=obj_type):
-            name = "cf_{}".format(cf.slug)
+            name = f"cf_{cf.slug}"
             self.base_columns[name] = CustomFieldColumn(cf)
 
         for cpf in ComputedField.objects.filter(content_type=obj_type):
@@ -49,8 +49,8 @@ class BaseTable(tables.Table):
             self.empty_text = f"No {self._meta.model._meta.verbose_name_plural} found"
 
         # Hide non-default columns
-        default_columns = list(getattr(self.Meta, "default_columns", list()))
-        extra_columns = [c[0] for c in kwargs.get("extra_columns", list())]  # extra_columns is a list of tuples
+        default_columns = list(getattr(self.Meta, "default_columns", []))
+        extra_columns = [c[0] for c in kwargs.get("extra_columns", [])]  # extra_columns is a list of tuples
         if default_columns:
             for column in self.columns:
                 if column.name not in default_columns and column.name not in extra_columns:
@@ -218,7 +218,7 @@ class ButtonsColumn(tables.TemplateColumn):
             }
         )
 
-    def header(self):
+    def header(self):  # pylint: disable=invalid-overridden-method
         return ""
 
 
@@ -228,7 +228,7 @@ class ChoiceFieldColumn(tables.Column):
     choices. The CSS class is derived by calling .get_FOO_class() on the row record.
     """
 
-    def render(self, record, bound_column, value):
+    def render(self, record, bound_column, value):  # pylint: disable=arguments-differ
         if value:
             name = bound_column.name
             css_class = getattr(record, f"get_{name}_class")()
@@ -275,7 +275,7 @@ class LinkedCountColumn(tables.Column):
         self.url_params = url_params
         super().__init__(*args, default=default, **kwargs)
 
-    def render(self, record, value):
+    def render(self, record, value):  # pylint: disable=arguments-differ
         if value:
             url = reverse(self.viewname, kwargs=self.view_kwargs)
             if self.url_params:
@@ -362,7 +362,7 @@ class CustomFieldColumn(tables.Column):
 
         super().__init__(*args, **kwargs)
 
-    def render(self, record, bound_column, value):
+    def render(self, record, bound_column, value):  # pylint: disable=arguments-differ
         if value is None:
             return self.default
 
