@@ -1,5 +1,6 @@
+from typing import Optional, Sequence, Union
+
 from django.conf import settings
-from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 from django.urls import reverse
 from django.test import override_settings, tag
@@ -9,7 +10,10 @@ from rest_framework.test import APIClient, APITransactionTestCase as _APITransac
 
 from nautobot.users.models import ObjectPermission, Token
 from nautobot.extras.choices import ObjectChangeActionChoices
-from nautobot.extras.models import ObjectChange
+from nautobot.extras.models import ChangeLoggedModel
+from nautobot.extras.registry import registry
+from nautobot.utilities.testing.mixins import NautobotTestCaseMixin
+from nautobot.utilities.utils import get_changes_for_model, get_filterset_for_model
 from .utils import disable_warnings
 from .views import ModelTestCase
 
@@ -20,15 +24,12 @@ __all__ = (
 )
 
 
-# Use the proper swappable User model
-User = get_user_model()
-
-
 #
 # REST API Tests
 #
 
 
+@tag("api")
 class APITestCase(ModelTestCase):
     """
     Base test case for API requests.
@@ -44,13 +45,12 @@ class APITestCase(ModelTestCase):
 
     def setUp(self):
         """
-        Create a superuser and token for API calls.
+        Create a token for API calls.
         """
-        # Create the test user and assign permissions
-        self.user = User.objects.create_user(username="testuser")
-        self.add_permissions(*self.user_permissions)
+        # Do not initialize the client, it conflicts with the APIClient.
+        super().setUpNautobot(client=False)
         self.token = Token.objects.create(user=self.user)
-        self.header = {"HTTP_AUTHORIZATION": "Token {}".format(self.token.key)}
+        self.header = {"HTTP_AUTHORIZATION": f"Token {self.token.key}"}
         if self.api_version:
             self.set_api_version(self.api_version)
 
@@ -130,14 +130,63 @@ class APIViewTestCases:
             obj_perm.users.add(self.user)
             obj_perm.object_types.add(ContentType.objects.get_for_model(self.model))
 
-            # Try GET to permitted object
-            url = self._get_detail_url(instance1)
-            self.assertHttpStatus(self.client.get(url, **self.header), status.HTTP_200_OK)
-
             # Try GET to non-permitted object
             url = self._get_detail_url(instance2)
             self.assertHttpStatus(self.client.get(url, **self.header), status.HTTP_404_NOT_FOUND)
 
+            # Try GET to permitted object
+            url = self._get_detail_url(instance1)
+            response = self.client.get(url, **self.header)
+            self.assertHttpStatus(response, status.HTTP_200_OK)
+            self.assertIsInstance(response.data, dict)
+            # Fields that should be present in *ALL* model serializers:
+            self.assertIn("id", response.data)
+            self.assertEqual(str(response.data["id"]), str(instance1.pk))  # coerce to str to handle both int and uuid
+            self.assertIn("url", response.data)
+            self.assertIn("display", response.data)
+            self.assertIsInstance(response.data["display"], str)
+            # Fields that should be present in appropriate model serializers:
+            if issubclass(self.model, ChangeLoggedModel):
+                self.assertIn("created", response.data)
+                self.assertIn("last_updated", response.data)
+            # Fields that should be absent by default (opt-in fields):
+            self.assertNotIn("computed_fields", response.data)
+            self.assertNotIn("relationships", response.data)
+
+            # If opt-in fields are supported on this model, make sure they can be opted into
+
+            custom_fields_registry = registry["model_features"]["custom_fields"]
+            # computed fields and custom fields use the same registry
+            cf_supported = self.model._meta.model_name in custom_fields_registry.get(self.model._meta.app_label, {})
+            if cf_supported:  # custom_fields is not an opt-in field, it should always be present if supported
+                self.assertIn("custom_fields", response.data)
+                self.assertIsInstance(response.data["custom_fields"], dict)
+
+            relationships_registry = registry["model_features"]["relationships"]
+            rel_supported = self.model._meta.model_name in relationships_registry.get(self.model._meta.app_label, {})
+            if cf_supported or rel_supported:
+                query_params = []
+                if cf_supported:
+                    query_params.append("include=computed_fields")
+                if rel_supported:
+                    query_params.append("include=relationships")
+                query_string = "&".join(query_params)
+                url = f"{url}?{query_string}"
+
+                response = self.client.get(url, **self.header)
+                self.assertHttpStatus(response, status.HTTP_200_OK)
+                self.assertIsInstance(response.data, dict)
+                if cf_supported:
+                    self.assertIn("computed_fields", response.data)
+                    self.assertIsInstance(response.data["computed_fields"], dict)
+                else:
+                    self.assertNotIn("computed_fields", response.data)
+                if rel_supported:
+                    self.assertIn("relationships", response.data)
+                    self.assertIsInstance(response.data["relationships"], dict)
+                else:
+                    self.assertNotIn("relationships", response.data)
+
         @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
         def test_options_object(self):
             """
@@ -150,6 +199,10 @@ class APIViewTestCases:
     class ListObjectsViewTestCase(APITestCase):
         brief_fields = []
         choices_fields = None
+        filterset = None
+
+        def get_filterset(self):
+            return self.filterset or get_filterset_for_model(self.model)
 
         @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
         def test_list_objects_anonymous(self):
@@ -165,6 +218,7 @@ class APIViewTestCases:
                 with disable_warnings("django.request"):
                     self.assertHttpStatus(self.client.get(url, **self.header), status.HTTP_403_FORBIDDEN)
             else:
+                # TODO FIXME: if we're passing **self.header, we are *by definition* **NOT** anonymous!!
                 response = self.client.get(url, **self.header)
                 self.assertHttpStatus(response, status.HTTP_200_OK)
                 self.assertIsInstance(response.data, dict)
@@ -226,6 +280,60 @@ class APIViewTestCases:
             self.assertIn("results", response.data)
             self.assertEqual(len(response.data["results"]), 2)
 
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
+        def test_list_objects_filtered(self):
+            """
+            GET a list of objects filtered by ID.
+            """
+            self.assertGreaterEqual(
+                self._get_queryset().count(),
+                3,
+                f"Test requires the creation of at least three {self.model} instances",
+            )
+            self.add_permissions(f"{self.model._meta.app_label}.view_{self.model._meta.model_name}")
+            instance1, instance2 = self._get_queryset()[:2]
+            response = self.client.get(f"{self._get_list_url()}?id={instance1.pk}&id={instance2.pk}", **self.header)
+            self.assertHttpStatus(response, status.HTTP_200_OK)
+            self.assertIsInstance(response.data, dict)
+            self.assertIn("results", response.data)
+            self.assertEqual(len(response.data["results"]), 2)
+            for entry in response.data["results"]:
+                self.assertIn(str(entry["id"]), [str(instance1.pk), str(instance2.pk)])
+
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=[], STRICT_FILTERING=True)
+        def test_list_objects_unknown_filter_strict_filtering(self):
+            """
+            GET a list of objects with an unknown filter parameter and strict filtering, expect a 400 response.
+            """
+            self.add_permissions(f"{self.model._meta.app_label}.view_{self.model._meta.model_name}")
+            with disable_warnings("django.request"):
+                response = self.client.get(f"{self._get_list_url()}?ice_cream_flavor=rocky-road", **self.header)
+            self.assertHttpStatus(response, status.HTTP_400_BAD_REQUEST)
+            self.assertIsInstance(response.data, dict)
+            self.assertIn("ice_cream_flavor", response.data)
+            self.assertIsInstance(response.data["ice_cream_flavor"], list)
+            self.assertEqual("Unknown filter field", str(response.data["ice_cream_flavor"][0]))
+
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=[], STRICT_FILTERING=False)
+        def test_list_objects_unknown_filter_no_strict_filtering(self):
+            """
+            GET a list of objects with an unknown filter parameter and no strict filtering, expect it to be ignored.
+            """
+            self.add_permissions(f"{self.model._meta.app_label}.view_{self.model._meta.model_name}")
+            with self.assertLogs("nautobot.utilities.filters") as cm:
+                response = self.client.get(f"{self._get_list_url()}?ice_cream_flavor=rocky-road", **self.header)
+            self.assertEqual(
+                cm.output,
+                [
+                    f"WARNING:nautobot.utilities.filters:{self.get_filterset().__name__}: "
+                    'Unknown filter field "ice_cream_flavor"',
+                ],
+            )
+            self.assertHttpStatus(response, status.HTTP_200_OK)
+            self.assertIsInstance(response.data, dict)
+            self.assertIn("results", response.data)
+            self.assertEqual(len(response.data["results"]), self._get_queryset().count())
+
         @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
         def test_options_objects(self):
             """
@@ -234,65 +342,6 @@ class APIViewTestCases:
             response = self.client.options(self._get_list_url(), **self.header)
             self.assertHttpStatus(response, status.HTTP_200_OK)
 
-        @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
-        def test_options_objects_returns_display_and_value(self):
-            """
-            Make an OPTIONS request for a list endpoint and validate choices use the display and value keys.
-            """
-            # Save self.user as superuser to be able to view available choices on list views.
-            self.user.is_superuser = True
-            self.user.save()
-
-            response = self.client.options(self._get_list_url(), **self.header)
-            self.assertHttpStatus(response, status.HTTP_200_OK)
-            data = response.json()
-
-            self.assertIn("actions", data)
-
-            # Grab any field that has choices defined (fields with enums)
-            if "POST" in data["actions"]:
-                field_choices = {k: v["choices"] for k, v in data["actions"]["POST"].items() if "choices" in v}
-            elif "PUT" in data["actions"]:  # JobModelViewSet supports editing but not creation
-                field_choices = {k: v["choices"] for k, v in data["actions"]["PUT"].items() if "choices" in v}
-            else:
-                self.fail(f"Neither PUT nor POST are available actions in: {data['actions']}")
-
-            # Will successfully assert if field_choices has entries and will not fail if model as no enum choices
-            # Broken down to provide better failure messages
-            for field, choices in field_choices.items():
-                for choice in choices:
-                    self.assertIn("display", choice, f"A choice in {field} is missing the display key")
-                    self.assertIn("value", choice, f"A choice in {field} is missing the value key")
-
-        @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
-        def test_options_returns_expected_choices(self):
-            """
-            Make an OPTIONS request for a list endpoint and validate choice fields match expected choice fields for serializer.
-            """
-            # Set to self.choices_fields as empty set to compare classes that shouldn't have any choice fields on serializer.
-            if not self.choices_fields:
-                self.choices_fields = set()
-
-            # Save self.user as superuser to be able to view available choices on list views.
-            self.user.is_superuser = True
-            self.user.save()
-
-            response = self.client.options(self._get_list_url(), **self.header)
-            self.assertHttpStatus(response, status.HTTP_200_OK)
-            data = response.json()
-
-            self.assertIn("actions", data)
-
-            # Grab any field name that has choices defined (fields with enums)
-            if "POST" in data["actions"]:
-                field_choices = {k for k, v in data["actions"]["POST"].items() if "choices" in v}
-            elif "PUT" in data["actions"]:  # JobModelViewSet supports editing but not creation
-                field_choices = {k for k, v in data["actions"]["PUT"].items() if "choices" in v}
-            else:
-                self.fail(f"Neither PUT nor POST are available actions in: {data['actions']}")
-
-            self.assertEqual(set(self.choices_fields), field_choices)
-
         @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
         def test_status_options_returns_expected_choices(self):
             # Set to self.choices_fields as empty set to compare classes that shouldn't have any choice fields on serializer.
@@ -327,7 +376,8 @@ class APIViewTestCases:
     class CreateObjectViewTestCase(APITestCase):
         create_data = []
         validation_excluded_fields = []
-        slug_source = None
+        slug_source: Optional[Union[str, Sequence[str]]] = None
+        slugify_function = staticmethod(slugify)
 
         def test_create_object_without_permission(self):
             """
@@ -340,6 +390,26 @@ class APIViewTestCases:
                 response = self.client.post(url, self.create_data[0], format="json", **self.header)
                 self.assertHttpStatus(response, status.HTTP_403_FORBIDDEN)
 
+        def check_expected_slug(self, obj):
+            slug_source = self.slug_source if isinstance(self.slug_source, (list, tuple)) else [self.slug_source]
+            expected_slug = ""
+            for source_item in slug_source:
+                # e.g. self.slug_source = ["parent__name", "name"]
+                source_keys = source_item.split("__")
+                try:
+                    val = getattr(obj, source_keys[0])
+                    for key in source_keys[1:]:
+                        val = getattr(val, key)
+                except AttributeError:
+                    val = ""
+                if val:
+                    if expected_slug != "":
+                        expected_slug += "-"
+                    expected_slug += self.slugify_function(val)
+
+            self.assertNotEqual(expected_slug, "")
+            self.assertEqual(obj.slug, expected_slug)
+
         def test_create_object(self):
             """
             POST a single object with permission.
@@ -362,17 +432,14 @@ class APIViewTestCases:
                     exclude=self.validation_excluded_fields,
                     api=True,
                 )
+
                 # Check if Slug field is automatically created
                 if self.slug_source is not None and "slug" not in create_data:
-                    object = self._get_queryset().get(pk=response.data["id"])
-                    expected_slug = slugify(getattr(object, self.slug_source))
-                    self.assertEqual(object.slug, expected_slug)
+                    self.check_expected_slug(self._get_queryset().get(pk=response.data["id"]))
 
                 # Verify ObjectChange creation
                 if hasattr(self.model, "to_objectchange"):
-                    objectchanges = ObjectChange.objects.filter(
-                        changed_object_type=ContentType.objects.get_for_model(instance), changed_object_id=instance.pk
-                    )
+                    objectchanges = get_changes_for_model(instance)
                     self.assertEqual(len(objectchanges), 1)
                     self.assertEqual(objectchanges[0].action, ObjectChangeActionChoices.ACTION_CREATE)
 
@@ -407,14 +474,13 @@ class APIViewTestCases:
                     api=True,
                 )
                 if self.slug_source is not None and "slug" not in self.create_data[i]:
-                    object = self._get_queryset().get(pk=obj["id"])
-                    expected_slug = slugify(getattr(object, self.slug_source))
-                    self.assertEqual(object.slug, expected_slug)
+                    self.check_expected_slug(self._get_queryset().get(pk=obj["id"]))
 
     class UpdateObjectViewTestCase(APITestCase):
         update_data = {}
-        bulk_update_data = None
+        bulk_update_data: Optional[dict] = None
         validation_excluded_fields = []
+        choices_fields = None
 
         def test_update_object_without_permission(self):
             """
@@ -449,9 +515,7 @@ class APIViewTestCases:
 
             # Verify ObjectChange creation
             if hasattr(self.model, "to_objectchange"):
-                objectchanges = ObjectChange.objects.filter(
-                    changed_object_type=ContentType.objects.get_for_model(instance), changed_object_id=instance.pk
-                )
+                objectchanges = get_changes_for_model(instance)
                 self.assertEqual(len(objectchanges), 1)
                 self.assertEqual(objectchanges[0].action, ObjectChangeActionChoices.ACTION_UPDATE)
 
@@ -475,12 +539,13 @@ class APIViewTestCases:
             response = self.client.patch(self._get_list_url(), data, format="json", **self.header)
             self.assertHttpStatus(response, status.HTTP_200_OK)
             for i, obj in enumerate(response.data):
-                for field in self.bulk_update_data:
+                for field, _value in self.bulk_update_data.items():
                     self.assertIn(
                         field,
                         obj,
                         f"Bulk update field '{field}' missing from object {i} in response",
                     )
+                    # TODO: shouldn't we also check that obj[field] == value?
             for instance in self._get_queryset().filter(pk__in=id_list):
                 self.assertInstanceEqual(
                     instance,
@@ -489,6 +554,65 @@ class APIViewTestCases:
                     api=True,
                 )
 
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
+        def test_options_objects_returns_display_and_value(self):
+            """
+            Make an OPTIONS request for a list endpoint and validate choices use the display and value keys.
+            """
+            # Save self.user as superuser to be able to view available choices on list views.
+            self.user.is_superuser = True
+            self.user.save()
+
+            response = self.client.options(self._get_list_url(), **self.header)
+            self.assertHttpStatus(response, status.HTTP_200_OK)
+            data = response.json()
+
+            self.assertIn("actions", data)
+
+            # Grab any field that has choices defined (fields with enums)
+            if "POST" in data["actions"]:
+                field_choices = {k: v["choices"] for k, v in data["actions"]["POST"].items() if "choices" in v}
+            elif "PUT" in data["actions"]:  # JobModelViewSet supports editing but not creation
+                field_choices = {k: v["choices"] for k, v in data["actions"]["PUT"].items() if "choices" in v}
+            else:
+                self.fail(f"Neither PUT nor POST are available actions in: {data['actions']}")
+
+            # Will successfully assert if field_choices has entries and will not fail if model as no enum choices
+            # Broken down to provide better failure messages
+            for field, choices in field_choices.items():
+                for choice in choices:
+                    self.assertIn("display", choice, f"A choice in {field} is missing the display key")
+                    self.assertIn("value", choice, f"A choice in {field} is missing the value key")
+
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
+        def test_options_returns_expected_choices(self):
+            """
+            Make an OPTIONS request for a list endpoint and validate choices match expected choices for serializer.
+            """
+            # Set self.choices_fields as empty set to compare classes that shouldn't have any choices on serializer.
+            if not self.choices_fields:
+                self.choices_fields = set()
+
+            # Save self.user as superuser to be able to view available choices on list views.
+            self.user.is_superuser = True
+            self.user.save()
+
+            response = self.client.options(self._get_list_url(), **self.header)
+            self.assertHttpStatus(response, status.HTTP_200_OK)
+            data = response.json()
+
+            self.assertIn("actions", data)
+
+            # Grab any field name that has choices defined (fields with enums)
+            if "POST" in data["actions"]:
+                field_choices = {k for k, v in data["actions"]["POST"].items() if "choices" in v}
+            elif "PUT" in data["actions"]:  # JobModelViewSet supports editing but not creation
+                field_choices = {k for k, v in data["actions"]["PUT"].items() if "choices" in v}
+            else:
+                self.fail(f"Neither PUT nor POST are available actions in: {data['actions']}")
+
+            self.assertEqual(set(self.choices_fields), field_choices)
+
     class DeleteObjectViewTestCase(APITestCase):
         def test_delete_object_without_permission(self):
             """
@@ -520,9 +644,7 @@ class APIViewTestCases:
 
             # Verify ObjectChange creation
             if hasattr(self.model, "to_objectchange"):
-                objectchanges = ObjectChange.objects.filter(
-                    changed_object_type=ContentType.objects.get_for_model(instance), changed_object_id=instance.pk
-                )
+                objectchanges = get_changes_for_model(instance)
                 self.assertEqual(len(objectchanges), 1)
                 self.assertEqual(objectchanges[0].action, ObjectChangeActionChoices.ACTION_DELETE)
 
@@ -543,33 +665,47 @@ class APIViewTestCases:
             self.assertHttpStatus(response, status.HTTP_204_NO_CONTENT)
             self.assertEqual(self._get_queryset().count(), 0)
 
+    class NotesURLViewTestCase(APITestCase):
+        """Validate Notes URL on objects that have the Note model Mixin."""
+
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
+        def test_notes_url_on_object(self):
+            if hasattr(self.model, "notes"):
+                instance1 = self._get_queryset().first()
+                # Add object-level permission
+                obj_perm = ObjectPermission(
+                    name="Test permission",
+                    constraints={"pk": instance1.pk},
+                    actions=["view"],
+                )
+                obj_perm.save()
+                obj_perm.users.add(self.user)
+                obj_perm.object_types.add(ContentType.objects.get_for_model(self.model))
+                url = self._get_detail_url(instance1)
+                response = self.client.get(url, **self.header)
+                self.assertHttpStatus(response, status.HTTP_200_OK)
+                self.assertIn("notes_url", response.data)
+                self.assertIn(f"{url}notes/", str(response.data["notes_url"]))
+
     class APIViewTestCase(
         GetObjectViewTestCase,
         ListObjectsViewTestCase,
         CreateObjectViewTestCase,
         UpdateObjectViewTestCase,
         DeleteObjectViewTestCase,
+        NotesURLViewTestCase,
     ):
         pass
 
 
 @tag("unit")
-class APITransactionTestCase(_APITransactionTestCase):
+class APITransactionTestCase(_APITransactionTestCase, NautobotTestCaseMixin):
     def setUp(self):
         """
         Create a superuser and token for API calls.
         """
-        self.user = User.objects.create(username="testuser", is_superuser=True)
+        super().setUpNautobot()
+        self.user.is_superuser = True
+        self.user.save()
         self.token = Token.objects.create(user=self.user)
-        self.header = {"HTTP_AUTHORIZATION": "Token {}".format(self.token.key)}
-
-    def assertHttpStatus(self, response, expected_status):
-        """
-        Provide more detail in the event of an unexpected HTTP response.
-        """
-        err_message = "Expected HTTP status {}; received {}: {}"
-        self.assertEqual(
-            response.status_code,
-            expected_status,
-            err_message.format(expected_status, response.status_code, response.data),
-        )
+        self.header = {"HTTP_AUTHORIZATION": f"Token {self.token.key}"}
