@@ -1,9 +1,12 @@
-from django.test import TestCase
+from django.contrib.contenttypes.models import ContentType
 
-from nautobot.dcim.models import DeviceRole, Platform, Region, Site
-from nautobot.extras.models import Status
-from nautobot.ipam.models import IPAddress
+from nautobot.dcim.choices import InterfaceModeChoices
+from nautobot.dcim.models import Device, DeviceRole, DeviceType, Manufacturer, Platform, Region, Site
+from nautobot.extras.models import Status, Tag
+from nautobot.ipam.choices import ServiceProtocolChoices
+from nautobot.ipam.models import IPAddress, VLAN, Service
 from nautobot.tenancy.models import Tenant, TenantGroup
+from nautobot.utilities.testing import FilterTestCases
 from nautobot.virtualization.filters import (
     ClusterTypeFilterSet,
     ClusterGroupFilterSet,
@@ -20,63 +23,82 @@ from nautobot.virtualization.models import (
 )
 
 
-class ClusterTypeTestCase(TestCase):
+class ClusterTypeTestCase(FilterTestCases.NameSlugFilterTestCase):
     queryset = ClusterType.objects.all()
     filterset = ClusterTypeFilterSet
 
     @classmethod
     def setUpTestData(cls):
 
-        ClusterType.objects.create(name="Cluster Type 1", slug="cluster-type-1", description="A")
-        ClusterType.objects.create(name="Cluster Type 2", slug="cluster-type-2", description="B")
-        ClusterType.objects.create(name="Cluster Type 3", slug="cluster-type-3", description="C")
+        cluster_types = (
+            ClusterType.objects.create(name="Cluster Type 1", slug="cluster-type-1", description="A"),
+            ClusterType.objects.create(name="Cluster Type 2", slug="cluster-type-2", description="B"),
+            ClusterType.objects.create(name="Cluster Type 3", slug="cluster-type-3", description="C"),
+        )
 
-    def test_id(self):
-        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-
-    def test_name(self):
-        params = {"name": ["Cluster Type 1", "Cluster Type 2"]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-
-    def test_slug(self):
-        params = {"slug": ["cluster-type-1", "cluster-type-2"]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        cls.clusters = [
+            Cluster.objects.create(name="Cluster 1", type=cluster_types[0]),
+            Cluster.objects.create(name="Cluster 2", type=cluster_types[1]),
+        ]
 
     def test_description(self):
         params = {"description": ["A", "B"]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
+    def test_clusters(self):
+        with self.subTest("Clusters"):
+            params = {"clusters": [self.clusters[0].pk, self.clusters[1].name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
-class ClusterGroupTestCase(TestCase):
+        with self.subTest("Has Clusters"):
+            params = {"has_clusters": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+            params = {"has_clusters": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+
+class ClusterGroupTestCase(FilterTestCases.NameSlugFilterTestCase):
     queryset = ClusterGroup.objects.all()
     filterset = ClusterGroupFilterSet
 
     @classmethod
     def setUpTestData(cls):
 
-        ClusterGroup.objects.create(name="Cluster Group 1", slug="cluster-group-1", description="A")
-        ClusterGroup.objects.create(name="Cluster Group 2", slug="cluster-group-2", description="B")
-        ClusterGroup.objects.create(name="Cluster Group 3", slug="cluster-group-3", description="C")
+        cluster_groups = (
+            ClusterGroup.objects.create(name="Cluster Group 1", slug="cluster-group-1", description="A"),
+            ClusterGroup.objects.create(name="Cluster Group 2", slug="cluster-group-2", description="B"),
+            ClusterGroup.objects.create(name="Cluster Group 3", slug="cluster-group-3", description="C"),
+        )
 
-    def test_id(self):
-        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        cluster_types = (
+            ClusterType.objects.create(name="Cluster Type 1", slug="cluster-type-1"),
+            ClusterType.objects.create(name="Cluster Type 2", slug="cluster-type-2"),
+        )
 
-    def test_name(self):
-        params = {"name": ["Cluster Group 1", "Cluster Group 2"]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-
-    def test_slug(self):
-        params = {"slug": ["cluster-group-1", "cluster-group-2"]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        cls.clusters = (
+            Cluster.objects.create(name="Cluster 1", type=cluster_types[0], group=cluster_groups[0]),
+            Cluster.objects.create(name="Cluster 2", type=cluster_types[1], group=cluster_groups[1]),
+        )
 
     def test_description(self):
         params = {"description": ["A", "B"]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
+    def test_clusters(self):
+        with self.subTest("Clusters"):
+            params = {"clusters": [self.clusters[0].pk, self.clusters[1].name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
-class ClusterTestCase(TestCase):
+        with self.subTest("Has Clusters"):
+            params = {"has_clusters": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+            params = {"has_clusters": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+
+class ClusterTestCase(FilterTestCases.FilterTestCase):
     queryset = Cluster.objects.all()
     filterset = ClusterFilterSet
 
@@ -119,36 +141,85 @@ class ClusterTestCase(TestCase):
             Tenant.objects.create(name="Tenant 3", slug="tenant-3", group=tenant_groups[2]),
         )
 
-        Cluster.objects.create(
-            name="Cluster 1",
-            type=cluster_types[0],
-            group=cluster_groups[0],
-            site=sites[0],
-            tenant=tenants[0],
-        )
-        Cluster.objects.create(
-            name="Cluster 2",
-            type=cluster_types[1],
-            group=cluster_groups[1],
-            site=sites[1],
-            tenant=tenants[1],
-        )
-        Cluster.objects.create(
-            name="Cluster 3",
-            type=cluster_types[2],
-            group=cluster_groups[2],
-            site=sites[2],
-            tenant=tenants[2],
+        clusters = (
+            Cluster.objects.create(
+                name="Cluster 1",
+                type=cluster_types[0],
+                group=cluster_groups[0],
+                site=sites[0],
+                tenant=tenants[0],
+                comments="This is cluster 1",
+            ),
+            Cluster.objects.create(
+                name="Cluster 2",
+                type=cluster_types[1],
+                group=cluster_groups[1],
+                site=sites[1],
+                tenant=tenants[1],
+                comments="This is cluster 2",
+            ),
+            Cluster.objects.create(
+                name="Cluster 3",
+                type=cluster_types[2],
+                group=cluster_groups[2],
+                site=sites[2],
+                tenant=tenants[2],
+                comments="This is cluster 3",
+            ),
         )
 
-    def test_id(self):
-        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        manufacturer = Manufacturer.objects.create(name="Manufacturer 1", slug="manufacturer-1")
+        devicetype = DeviceType.objects.create(manufacturer=manufacturer, model="Device Type", slug="device-type")
+        devicerole = DeviceRole.objects.create(name="Device Role", slug="device-role", color="ff0000")
+
+        cls.device = Device.objects.create(
+            name="Device 1", device_type=devicetype, device_role=devicerole, site=sites[0], cluster=clusters[0]
+        )
+
+        cls.virtualmachine = VirtualMachine.objects.create(name="Virtual Machine 1", cluster=clusters[1])
+
+        tag = Tag.objects.create(name="Tag 1", slug="tag-1")
+        tag.content_types.add(ContentType.objects.get_for_model(Cluster))
+
+        clusters[0].tags.add(tag)
+        clusters[1].tags.add(tag)
 
     def test_name(self):
         params = {"name": ["Cluster 1", "Cluster 2"]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
+    def test_comments(self):
+        params = {"comments": ["This is cluster 1", "This is cluster 2"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_tags(self):
+        params = {"tag": ["tag-1"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_device(self):
+        with self.subTest("Devices"):
+            params = {"devices": [self.device.pk, self.device.name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+        with self.subTest("Has Devices"):
+            params = {"has_devices": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+            params = {"has_devices": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_virtual_machines(self):
+        with self.subTest("Virtual Machines"):
+            params = {"virtual_machines": [self.virtualmachine.pk, self.virtualmachine.name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+        with self.subTest("Has Virtual Machines"):
+            params = {"has_virtual_machines": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+            params = {"has_virtual_machines": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
     def test_region(self):
         regions = Region.objects.all()[:2]
         params = {"region_id": [regions[0].pk, regions[1].pk]}
@@ -197,7 +268,7 @@ class ClusterTestCase(TestCase):
         self.assertEqual(self.filterset(params, self.queryset).qs.values_list("pk", flat=True)[0], value)
 
 
-class VirtualMachineTestCase(TestCase):
+class VirtualMachineTestCase(FilterTestCases.FilterTestCase):
     queryset = VirtualMachine.objects.all()
     filterset = VirtualMachineFilterSet
 
@@ -288,6 +359,7 @@ class VirtualMachineTestCase(TestCase):
                 memory=1,
                 disk=1,
                 local_context_data={"foo": 123},
+                comments="This is VM 1",
             ),
             VirtualMachine.objects.create(
                 name="Virtual Machine 2",
@@ -299,6 +371,7 @@ class VirtualMachineTestCase(TestCase):
                 vcpus=2,
                 memory=2,
                 disk=2,
+                comments="This is VM 2",
             ),
             VirtualMachine.objects.create(
                 name="Virtual Machine 3",
@@ -310,10 +383,11 @@ class VirtualMachineTestCase(TestCase):
                 vcpus=3,
                 memory=3,
                 disk=3,
+                comments="This is VM 3",
             ),
         )
 
-        interfaces = (
+        cls.interfaces = (
             VMInterface.objects.create(
                 virtual_machine=vms[0],
                 name="Interface 1",
@@ -331,23 +405,80 @@ class VirtualMachineTestCase(TestCase):
             ),
         )
 
-        # Assign primary IPs for filtering
-        ipaddresses = (
-            IPAddress.objects.create(address="192.0.2.1/24", assigned_object=interfaces[0]),
-            IPAddress.objects.create(address="192.0.2.2/24", assigned_object=interfaces[1]),
+        cls.services = (
+            Service.objects.create(
+                virtual_machine=vms[1],
+                name="Service 1",
+                protocol=ServiceProtocolChoices.PROTOCOL_UDP,
+                ports=[2003],
+            ),
+            Service.objects.create(
+                virtual_machine=vms[2],
+                name="Service 2",
+                protocol=ServiceProtocolChoices.PROTOCOL_UDP,
+                ports=[2002],
+            ),
         )
 
-        VirtualMachine.objects.filter(pk=vms[0].pk).update(primary_ip4=ipaddresses[0])
-        VirtualMachine.objects.filter(pk=vms[1].pk).update(primary_ip4=ipaddresses[1])
+        # Assign primary IPs for filtering
+        cls.ipaddresses = (
+            IPAddress.objects.create(address="192.0.2.1/24", assigned_object=cls.interfaces[0]),
+            IPAddress.objects.create(address="fe80::8ef:3eff:fe4c:3895/24", assigned_object=cls.interfaces[1]),
+        )
 
-    def test_id(self):
-        params = {"id": self.queryset.values_list("pk", flat=True)[:2]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        VirtualMachine.objects.filter(pk=vms[0].pk).update(primary_ip4=cls.ipaddresses[0])
+        VirtualMachine.objects.filter(pk=vms[1].pk).update(primary_ip6=cls.ipaddresses[1])
+
+        tag = Tag.objects.create(name="Tag 1", slug="tag-1")
+        tag.content_types.add(ContentType.objects.get_for_model(VirtualMachine))
+
+        vms[0].tags.add(tag)
+        vms[1].tags.add(tag)
 
     def test_name(self):
         params = {"name": ["Virtual Machine 1", "Virtual Machine 2"]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
+    def test_comments(self):
+        params = {"comments": ["This is VM 1", "This is VM 2"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_primary_ip4(self):
+        params = {"primary_ip4": ["192.0.2.1/24", self.ipaddresses[0].pk]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+    def test_primary_ip6(self):
+        params = {"primary_ip6": ["fe80::8ef:3eff:fe4c:3895/24", self.ipaddresses[1].pk]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+    def test_services(self):
+        with self.subTest("Services"):
+            params = {"services": [self.services[0].pk, self.services[1].name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+        with self.subTest("Has Services"):
+            params = {"has_services": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+            params = {"has_services": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+    def test_interfaces(self):
+        with self.subTest("Interfaces"):
+            params = {"interfaces": [self.interfaces[0].pk, self.interfaces[1].pk]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+        with self.subTest("Has Interfaces"):
+            params = {"has_interfaces": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
+
+            params = {"has_interfaces": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 0)
+
+    def test_tags(self):
+        params = {"tag": ["tag-1"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
     def test_vcpus(self):
         params = {"vcpus": [1, 2]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
@@ -450,7 +581,7 @@ class VirtualMachineTestCase(TestCase):
         self.assertEqual(self.filterset(params, self.queryset).qs.values_list("pk", flat=True)[0], value)
 
 
-class VMInterfaceTestCase(TestCase):
+class VMInterfaceTestCase(FilterTestCases.FilterTestCase):
     queryset = VMInterface.objects.all()
     filterset = VMInterfaceFilterSet
 
@@ -475,43 +606,187 @@ class VMInterfaceTestCase(TestCase):
             VirtualMachine.objects.create(name="Virtual Machine 3", cluster=clusters[2]),
         )
 
-        VMInterface.objects.create(
-            virtual_machine=vms[0],
-            name="Interface 1",
-            enabled=True,
-            mtu=100,
-            mac_address="00-00-00-00-00-01",
-        )
-        VMInterface.objects.create(
-            virtual_machine=vms[1],
-            name="Interface 2",
-            enabled=True,
-            mtu=200,
-            mac_address="00-00-00-00-00-02",
-        )
-        VMInterface.objects.create(
-            virtual_machine=vms[2],
-            name="Interface 3",
-            enabled=False,
-            mtu=300,
-            mac_address="00-00-00-00-00-03",
+        statuses = Status.objects.get_for_model(VMInterface)
+
+        cls.vlan1 = VLAN.objects.create(name="VLAN 1", vid=1)
+        cls.vlan2 = VLAN.objects.create(name="VLAN 2", vid=2)
+
+        vminterfaces = (
+            VMInterface.objects.create(
+                virtual_machine=vms[0],
+                name="Interface 1",
+                enabled=True,
+                mtu=100,
+                mac_address="00-00-00-00-00-01",
+                status=statuses.get(slug="active"),
+                description="This is a description of Interface1",
+                mode=InterfaceModeChoices.MODE_ACCESS,
+                untagged_vlan=cls.vlan1,
+            ),
+            VMInterface.objects.create(
+                virtual_machine=vms[1],
+                name="Interface 2",
+                enabled=True,
+                mtu=200,
+                mac_address="00-00-00-00-00-02",
+                status=statuses.get(slug="active"),
+                description="This is a description of Interface2",
+                mode=InterfaceModeChoices.MODE_ACCESS,
+                untagged_vlan=cls.vlan2,
+            ),
+            VMInterface.objects.create(
+                virtual_machine=vms[2],
+                name="Interface 3",
+                enabled=False,
+                mtu=300,
+                mac_address="00-00-00-00-00-03",
+                status=statuses.get(slug="planned"),
+                description="This is a description of Interface3",
+                mode=InterfaceModeChoices.MODE_TAGGED,
+            ),
         )
 
-    def test_id(self):
-        id_list = self.queryset.values_list("id", flat=True)[:2]
-        params = {"id": [str(id) for id in id_list]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        vminterfaces[2].tagged_vlans.add(cls.vlan2)
+
+        # Assign primary IPs for filtering
+        IPAddress.objects.create(address="192.0.2.1/24", assigned_object=vminterfaces[0])
+        IPAddress.objects.create(address="fe80::8ef:3eff:fe4c:3895/24", assigned_object=vminterfaces[1])
+
+        tag = Tag.objects.create(name="Tag 1", slug="tag-1")
+        tag.content_types.add(ContentType.objects.get_for_model(VMInterface))
+
+        vminterfaces[0].tags.add(tag)
+        vminterfaces[1].tags.add(tag)
 
     def test_name(self):
         params = {"name": ["Interface 1", "Interface 2"]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
+    def test_description(self):
+        params = {"description": ["This is a description of Interface3", "This is a description of Interface2"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_tags(self):
+        params = {"tag": ["tag-1"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_tagged_vlans(self):
+        with self.subTest("Tagged VLANs"):
+            params = {"tagged_vlans": [self.vlan1.pk, self.vlan2.vid]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+        with self.subTest("Has Tagged VLANs"):
+            params = {"has_tagged_vlans": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+            params = {"has_tagged_vlans": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+    def test_untagged_vlan(self):
+        params = {"untagged_vlan": [self.vlan1.pk, self.vlan2.vid]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+    def test_mode(self):
+        params = {"mode": [InterfaceModeChoices.MODE_ACCESS, InterfaceModeChoices.MODE_TAGGED]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
+
+    def test_ip_addresses(self):
+        with self.subTest("Primary Addresses"):
+            ipaddress = IPAddress.objects.last()
+            params = {"ip_addresses": ["192.0.2.1/24", ipaddress.id]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
+        with self.subTest("Has Primary Addresses"):
+            params = {"has_ip_addresses": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+            params = {"has_ip_addresses": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
     def test_assigned_to_interface(self):
         params = {"enabled": "true"}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
         params = {"enabled": "false"}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
 
+    def test_parent(self):
+        # Create child interfaces
+        parent_interface = VMInterface.objects.first()
+        child_interfaces = (
+            VMInterface(
+                virtual_machine=parent_interface.virtual_machine, name="Child 1", parent_interface=parent_interface
+            ),
+            VMInterface(
+                virtual_machine=parent_interface.virtual_machine, name="Child 2", parent_interface=parent_interface
+            ),
+            VMInterface(
+                virtual_machine=parent_interface.virtual_machine, name="Child 3", parent_interface=parent_interface
+            ),
+        )
+        VMInterface.objects.bulk_create(child_interfaces)
+        params = {"parent_interface": [parent_interface.pk, parent_interface.name]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
+
+    def test_child(self):
+        # Create child interfaces
+        parent_interface = VMInterface.objects.first()
+        child_interfaces = (
+            VMInterface(
+                virtual_machine=parent_interface.virtual_machine, name="Child 1", parent_interface=parent_interface
+            ),
+            VMInterface(
+                virtual_machine=parent_interface.virtual_machine, name="Child 2", parent_interface=parent_interface
+            ),
+            VMInterface(
+                virtual_machine=parent_interface.virtual_machine, name="Child 3", parent_interface=parent_interface
+            ),
+        )
+        VMInterface.objects.bulk_create(child_interfaces)
+        with self.subTest("Child Interfaces"):
+            params = {"child_interfaces": [child_interfaces[0].pk, child_interfaces[1].name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+        with self.subTest("Has child Interfaces"):
+            params = {"has_child_interfaces": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+            params = {"has_child_interfaces": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 5)
+
+    def test_bridge(self):
+        # Create bridged interfaces
+        bridge_interface = VMInterface.objects.first()
+        bridged_interfaces = (
+            VMInterface(virtual_machine=bridge_interface.virtual_machine, name="Bridged 1", bridge=bridge_interface),
+            VMInterface(virtual_machine=bridge_interface.virtual_machine, name="Bridged 2", bridge=bridge_interface),
+            VMInterface(virtual_machine=bridge_interface.virtual_machine, name="Bridged 3", bridge=bridge_interface),
+        )
+        VMInterface.objects.bulk_create(bridged_interfaces)
+
+        params = {"bridge": [bridge_interface.pk, bridge_interface.name]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
+
+    def test_bridged_interfaces(self):
+        # Create bridged interfaces
+        bridge_interface = VMInterface.objects.first()
+        bridged_interfaces = (
+            VMInterface(virtual_machine=bridge_interface.virtual_machine, name="Bridged 1", bridge=bridge_interface),
+            VMInterface(virtual_machine=bridge_interface.virtual_machine, name="Bridged 2", bridge=bridge_interface),
+            VMInterface(virtual_machine=bridge_interface.virtual_machine, name="Bridged 3", bridge=bridge_interface),
+        )
+        VMInterface.objects.bulk_create(bridged_interfaces)
+
+        with self.subTest("Bridged Interfaces"):
+            params = {"bridged_interfaces": [bridged_interfaces[0].pk, bridged_interfaces[1].name]}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+        with self.subTest("Has Bridged Interfaces"):
+            params = {"has_bridged_interfaces": True}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 1)
+
+            params = {"has_bridged_interfaces": False}
+            self.assertEqual(self.filterset(params, self.queryset).qs.count(), 5)
+
     def test_mtu(self):
         params = {"mtu": [100, 200]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
@@ -527,6 +802,10 @@ class VMInterfaceTestCase(TestCase):
         params = {"mac_address": ["00-00-00-00-00-01", "00-00-00-00-00-02"]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
+    def test_status(self):
+        params = {"status": ["active"]}
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+
     def test_search(self):
         value = self.queryset.values_list("pk", flat=True)[0]
         params = {"q": value}
